==> qt6-webengine_6.2.4+dfsg.orig.tar.xz: qtwebengine-everywhere-src-6.2.4/src/3rdparty/chromium/components/component_updater/component_updater_command_line_config_policy.h <==
// Copyright 2018 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef COMPONENTS_COMPONENT_UPDATER_COMPONENT_UPDATER_COMMAND_LINE_CONFIG_POLICY_H_
#define COMPONENTS_COMPONENT_UPDATER_COMPONENT_UPDATER_COMMAND_LINE_CONFIG_POLICY_H_

#include "base/macros.h"
#include "components/update_client/command_line_config_policy.h"
#include "url/gurl.h"

namespace base {
class CommandLine;
}

namespace component_updater {

// Component updater config policy implementation.
class ComponentUpdaterCommandLineConfigPolicy final
    : public update_client::CommandLineConfigPolicy {
 public:
  explicit ComponentUpdaterCommandLineConfigPolicy(
      const base::CommandLine* cmdline);

  // update_client::CommandLineConfigPolicy overrides.
  bool BackgroundDownloadsEnabled() const override;
  bool DeltaUpdatesEnabled() const override;
  bool FastUpdate() const override;
  bool PingsEnabled() const override;
  bool TestRequest() const override;
  GURL UrlSourceOverride() const override;
  double InitialDelay() const override;

 private:
  bool background_downloads_enabled_ = false;
  bool deltas_enabled_ = true;
  bool fast_update_ = false;
  bool pings_enabled_ = true;
  bool test_request_ = false;

  // If non-zero, time interval in seconds until the first component
  // update check.
  double initial_delay_ = 0;

  GURL url_source_override_;

  DISALLOW_COPY_AND_ASSIGN(ComponentUpdaterCommandLineConfigPolicy);
};

}  // namespace component_updater

#endif  // COMPONENTS_COMPONENT_UPDATER_COMPONENT_UPDATER_COMMAND_LINE_CONFIG_POLICY_H_

==> qt6-webengine_6.6.2+dfsg.orig.tar.xz: qtwebengine-everywhere-src-6.6.2/src/3rdparty/chromium/components/component_updater/component_updater_command_line_config_policy.h <==
// Copyright 2018 The Chromium Authors
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef COMPONENTS_COMPONENT_UPDATER_COMPONENT_UPDATER_COMMAND_LINE_CONFIG_POLICY_H_
#define COMPONENTS_COMPONENT_UPDATER_COMPONENT_UPDATER_COMMAND_LINE_CONFIG_POLICY_H_

#include "base/time/time.h"
#include "components/update_client/command_line_config_policy.h"
#include "url/gurl.h"

namespace base {
class CommandLine;
}

namespace component_updater {

extern const char kSwitchTestRequestParam[];

// Component updater config policy implementation.
class ComponentUpdaterCommandLineConfigPolicy final
    : public update_client::CommandLineConfigPolicy {
 public:
  explicit ComponentUpdaterCommandLineConfigPolicy(
      const base::CommandLine* cmdline);

  ComponentUpdaterCommandLineConfigPolicy(
      const ComponentUpdaterCommandLineConfigPolicy&) = delete;
  ComponentUpdaterCommandLineConfigPolicy& operator=(
      const ComponentUpdaterCommandLineConfigPolicy&) = delete;

  // update_client::CommandLineConfigPolicy overrides.
  bool BackgroundDownloadsEnabled() const override;
  bool DeltaUpdatesEnabled() const override;
  bool FastUpdate() const override;
  bool PingsEnabled() const override;
  bool TestRequest() const override;
  GURL UrlSourceOverride() const override;
  base::TimeDelta InitialDelay() const override;

 private:
  bool background_downloads_enabled_ = false;
  bool deltas_enabled_ = true;
  bool fast_update_ = false;
  bool pings_enabled_ = true;
  bool test_request_ = false;

  // If non-zero, time interval until the first component update check.
  base::TimeDelta initial_delay_ = base::Seconds(0);

  GURL url_source_override_;
};

}  // namespace component_updater

#endif  // COMPONENTS_COMPONENT_UPDATER_COMPONENT_UPDATER_COMMAND_LINE_CONFIG_POLICY_H_
